@@ -14,14 +14,15 @@ def save_as_tsv(location, file_name, data):
     data: ordered dict
         Data to write to the tsv.
     """
+    
     full_file_path = location + file_name + ".tsv"
 
     if path.exists(full_file_path):
-        with open(full_file_path, "a+") as f:
+        with open(full_file_path, "a+", encoding="utf-8") as f:
             tsv_writer = csv.writer(f, delimiter='\t')
             tsv_writer.writerow(data.values())
     else:
-        with open(full_file_path, "w", newline='') as f:
+        with open(full_file_path, "w", newline='', encoding="utf-8") as f:
             tsv_writer = csv.writer(f, delimiter='\t')
             tsv_writer.writerow(data.keys())
             tsv_writer.writerow(data.values())
\ No newline at end of file
